@@ -63,7 +63,7 @@ class ManageFiles():
                         shutil.copyfileobj(raw, output)
                 
             # Return success message
-            return 'File Downloaded Successfully', file_key, file_extention, True
+            return 'File Downloaded Successfully', file_key, r.headers, True
         except Exception as err:
             return self.get_response(url)
 
